pub(super) fn positive<T>(key: &'static str, value: T) -> Result<T>where
T: Default + PartialOrd,Expand description
Requires a value greater than zero for types whose default is zero.
Errors
Returns anyhow::Error when the value is not greater than zero.